@@ -36,15 +36,14 @@ class PostgresEmbedder(EmbedderBase):
             self.embedding_configs[ext] = processor
 
     @logger.trace_function(log_execution=log_execution, log_args=log_args, log_result=False)
-    def embed_file(self, source_url: str, file_name: str, tenant_id: str):
-        logger.info(f"Embedding file: {file_name} from source: {source_url} for tenant: {tenant_id}")
+    def embed_file(self, source_url: str, file_name: str):
+        logger.info(f"Embedding file: {file_name} from source: {source_url}")
         file_extension = file_name.split(".")[-1].lower()
         embedding_config = self.embedding_configs.get(file_extension)
         self.__embed(
             source_url=source_url,
             file_extension=file_extension,
-            embedding_config=embedding_config,
-            tenant_id=tenant_id
+            embedding_config=embedding_config
         )
         if file_extension != "url" and self.storage_client:
             # Update blob metadata using storage_account
@@ -56,7 +55,7 @@ class PostgresEmbedder(EmbedderBase):
 
     @logger.trace_function(log_execution=log_execution, log_args=False, log_result=log_result)
     def __embed(
-        self, source_url: str, file_extension: str, embedding_config: EmbeddingConfig, tenant_id: str
+        self, source_url: str, file_extension: str, embedding_config: EmbeddingConfig
     ):
         logger.info(f"Starting embedding process for source: {source_url}")
         documents_to_upload: List[SourceDocument] = []
@@ -82,7 +81,7 @@ class PostgresEmbedder(EmbedderBase):
             logger.info("Chunked into document chunks.")
 
             for document in documents:
-                documents_to_upload.append(self.__convert_to_search_document(document, tenant_id))
+                documents_to_upload.append(self.__convert_to_search_document(document))
 
         if documents_to_upload:
             logger.info(
@@ -93,7 +92,7 @@ class PostgresEmbedder(EmbedderBase):
             logger.warning("No documents to upload.")
 
     @logger.trace_function(log_execution=log_execution, log_args=False, log_result=False)
-    def __convert_to_search_document(self, document: SourceDocument, tenant_id: str):
+    def __convert_to_search_document(self, document: SourceDocument):
         logger.info(f"Generating embeddings for document ID: {document.id}")
         embedded_content = self.llm_helper.generate_embeddings(document.content)
         metadata = {
@@ -108,7 +107,6 @@ class PostgresEmbedder(EmbedderBase):
         logger.info(f"Metadata generated for document ID: {document.id}")
         return {
             "id": document.id,
-            "tenant_id": tenant_id,
             "content": document.content,
             "content_vector": embedded_content,
             "metadata": json.dumps(metadata),
