@@ -21,9 +21,8 @@ class Orchestrator:
         chat_history: List[dict],
         conversation_id: str,
         user_info,
-        tenant_id: str = None,
         **kwargs: dict,
     ) -> dict:
         return self.orchestrator.handle_message(
-            user_message, chat_history, conversation_id, user_info, tenant_id, **kwargs
+            user_message, chat_history, conversation_id, user_info, **kwargs
         )
